package javaio;

import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class JavaFileIO {

	public static void main(String[] args) {
		/*
		 * 观察该project， 会发现data和src是平级目录 这里用的相对路径，指project下data文件夹下cats.txt文件
		 */
		List<Cat> myCats = getCatsFromFile("data/cats.txt");
		System.out.println("-----------Java File IO Example-----------");
		for (Cat cat : myCats) {
			// 这里调用了Cat的toString方法获取cat这个对象的信息
			System.out.println(cat);
		}

	}

	static List<Cat> getCatsFromFile(String fileName) {
		/*
		 * 用Java自带的File IO 读写文件数据, 从cats.csv中读取数据：每一行对应一只cat的三个属性. 获取所有猫的对象，保存在列表中并返回
		 */

		// 通过fileName创建一个文件（句柄）
		File file = new File(fileName);
		List<Cat> cats = new ArrayList<>();
		try {	// Java的异常处理机制，try{}catch(Exception e){}
			// 创建一个Scanner来逐行扫描文件
			Scanner fileScanner = new Scanner(file);
			// 如果扫描到文件有下一行
			while (fileScanner.hasNext()) {
				String line = fileScanner.nextLine(); // 读取一行
				line = line.trim(); // 删除这一行首尾的空格
				// 如果这一行（去除首位空格后）长度为0，或者以 # 开头，跳过
				if (line.trim().length() == 0 || line.startsWith("#")) {
					continue;
				}
				// 通过','(或后面有空格） 分割字符串，得到一个字符串数组
				String[] catProperties = line.split(",\\s*");
				// 如果分割后，这一行不是包含三个属性（对应于name, breed, age），为不完整数据行，跳过
				if (catProperties.length != 3) {
					continue;
				}
				Cat cat = new Cat();
				cat.name = catProperties[0].trim(); // 第0个属性为name，去除首尾空格
				cat.breed = catProperties[1].trim(); // 第1个属性为breed，去除首尾空格
				// 第三个属性去除首尾空格后，转换成整数，赋值给cat
				cat.age = Integer.parseInt(catProperties[2].trim());
				// 将cat添加进列表
				cats.add(cat);
			}
			// 关闭scanner
			fileScanner.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
		// 返回列表
		return cats;

	}

}
